==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_functions/mp7276_001/CopyStdWOData.java <==

package net.datastream.schemas.mp_functions.mp7276_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STDWOID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCESTDWO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESTSTDWO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCUSTOMFIELDS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCOMMENTS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYDOCUMENTS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYTRANSLATIONS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYWOCUSTOMFIELDS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYACTIVITIES"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYACTIVITYCOMMENTS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCHILDREN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYTOOLS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "sourcestdwo",
    "deststdwo",
    "copycustomfields",
    "copycomments",
    "copydocuments",
    "copytranslations",
    "copywocustomfields",
    "copyactivities",
    "copyactivitycomments",
    "copychildren",
    "copytools"
})
@XmlRootElement(name = "CopyStdWOData")
public class CopyStdWOData {

    @XmlElement(name = "SOURCESTDWO", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STDWOID_Type sourcestdwo;
    @XmlElement(name = "DESTSTDWO", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STDWOID_Type deststdwo;
    @XmlElement(name = "COPYCUSTOMFIELDS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copycustomfields;
    @XmlElement(name = "COPYCOMMENTS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copycomments;
    @XmlElement(name = "COPYDOCUMENTS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copydocuments;
    @XmlElement(name = "COPYTRANSLATIONS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copytranslations;
    @XmlElement(name = "COPYWOCUSTOMFIELDS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copywocustomfields;
    @XmlElement(name = "COPYACTIVITIES", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copyactivities;
    @XmlElement(name = "COPYACTIVITYCOMMENTS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copyactivitycomments;
    @XmlElement(name = "COPYCHILDREN", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copychildren;
    @XmlElement(name = "COPYTOOLS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copytools;

    /**
     * Obtient la valeur de la propriété sourcestdwo.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getSOURCESTDWO() {
        return sourcestdwo;
    }

    /**
     * Définit la valeur de la propriété sourcestdwo.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setSOURCESTDWO(STDWOID_Type value) {
        this.sourcestdwo = value;
    }

    /**
     * Obtient la valeur de la propriété deststdwo.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getDESTSTDWO() {
        return deststdwo;
    }

    /**
     * Définit la valeur de la propriété deststdwo.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setDESTSTDWO(STDWOID_Type value) {
        this.deststdwo = value;
    }

    /**
     * Obtient la valeur de la propriété copycustomfields.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCUSTOMFIELDS() {
        return copycustomfields;
    }

    /**
     * Définit la valeur de la propriété copycustomfields.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCUSTOMFIELDS(String value) {
        this.copycustomfields = value;
    }

    /**
     * Obtient la valeur de la propriété copycomments.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCOMMENTS() {
        return copycomments;
    }

    /**
     * Définit la valeur de la propriété copycomments.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCOMMENTS(String value) {
        this.copycomments = value;
    }

    /**
     * Obtient la valeur de la propriété copydocuments.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYDOCUMENTS() {
        return copydocuments;
    }

    /**
     * Définit la valeur de la propriété copydocuments.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYDOCUMENTS(String value) {
        this.copydocuments = value;
    }

    /**
     * Obtient la valeur de la propriété copytranslations.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYTRANSLATIONS() {
        return copytranslations;
    }

    /**
     * Définit la valeur de la propriété copytranslations.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYTRANSLATIONS(String value) {
        this.copytranslations = value;
    }

    /**
     * Obtient la valeur de la propriété copywocustomfields.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYWOCUSTOMFIELDS() {
        return copywocustomfields;
    }

    /**
     * Définit la valeur de la propriété copywocustomfields.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYWOCUSTOMFIELDS(String value) {
        this.copywocustomfields = value;
    }

    /**
     * Obtient la valeur de la propriété copyactivities.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYACTIVITIES() {
        return copyactivities;
    }

    /**
     * Définit la valeur de la propriété copyactivities.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYACTIVITIES(String value) {
        this.copyactivities = value;
    }

    /**
     * Obtient la valeur de la propriété copyactivitycomments.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYACTIVITYCOMMENTS() {
        return copyactivitycomments;
    }

    /**
     * Définit la valeur de la propriété copyactivitycomments.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYACTIVITYCOMMENTS(String value) {
        this.copyactivitycomments = value;
    }

    /**
     * Obtient la valeur de la propriété copychildren.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCHILDREN() {
        return copychildren;
    }

    /**
     * Définit la valeur de la propriété copychildren.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCHILDREN(String value) {
        this.copychildren = value;
    }

    /**
     * Obtient la valeur de la propriété copytools.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYTOOLS() {
        return copytools;
    }

    /**
     * Définit la valeur de la propriété copytools.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYTOOLS(String value) {
        this.copytools = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_functions/mp7276_001/CopyStdWOData.java <==

package net.datastream.schemas.mp_functions.mp7276_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STDWOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCESTDWO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESTSTDWO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCUSTOMFIELDS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCOMMENTS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYDOCUMENTS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYTRANSLATIONS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYWOCUSTOMFIELDS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYACTIVITIES"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYACTIVITYCOMMENTS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYCHILDREN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COPYTOOLS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "sourcestdwo",
    "deststdwo",
    "copycustomfields",
    "copycomments",
    "copydocuments",
    "copytranslations",
    "copywocustomfields",
    "copyactivities",
    "copyactivitycomments",
    "copychildren",
    "copytools"
})
@XmlRootElement(name = "CopyStdWOData")
public class CopyStdWOData {

    @XmlElement(name = "SOURCESTDWO", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STDWOID_Type sourcestdwo;
    @XmlElement(name = "DESTSTDWO", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STDWOID_Type deststdwo;
    @XmlElement(name = "COPYCUSTOMFIELDS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copycustomfields;
    @XmlElement(name = "COPYCOMMENTS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copycomments;
    @XmlElement(name = "COPYDOCUMENTS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copydocuments;
    @XmlElement(name = "COPYTRANSLATIONS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copytranslations;
    @XmlElement(name = "COPYWOCUSTOMFIELDS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copywocustomfields;
    @XmlElement(name = "COPYACTIVITIES", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copyactivities;
    @XmlElement(name = "COPYACTIVITYCOMMENTS", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copyactivitycomments;
    @XmlElement(name = "COPYCHILDREN", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String copychildren;
    @XmlElement(name = "COPYTOOLS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String copytools;

    /**
     * Gets the value of the sourcestdwo property.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getSOURCESTDWO() {
        return sourcestdwo;
    }

    /**
     * Sets the value of the sourcestdwo property.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setSOURCESTDWO(STDWOID_Type value) {
        this.sourcestdwo = value;
    }

    /**
     * Gets the value of the deststdwo property.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getDESTSTDWO() {
        return deststdwo;
    }

    /**
     * Sets the value of the deststdwo property.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setDESTSTDWO(STDWOID_Type value) {
        this.deststdwo = value;
    }

    /**
     * Gets the value of the copycustomfields property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCUSTOMFIELDS() {
        return copycustomfields;
    }

    /**
     * Sets the value of the copycustomfields property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCUSTOMFIELDS(String value) {
        this.copycustomfields = value;
    }

    /**
     * Gets the value of the copycomments property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCOMMENTS() {
        return copycomments;
    }

    /**
     * Sets the value of the copycomments property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCOMMENTS(String value) {
        this.copycomments = value;
    }

    /**
     * Gets the value of the copydocuments property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYDOCUMENTS() {
        return copydocuments;
    }

    /**
     * Sets the value of the copydocuments property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYDOCUMENTS(String value) {
        this.copydocuments = value;
    }

    /**
     * Gets the value of the copytranslations property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYTRANSLATIONS() {
        return copytranslations;
    }

    /**
     * Sets the value of the copytranslations property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYTRANSLATIONS(String value) {
        this.copytranslations = value;
    }

    /**
     * Gets the value of the copywocustomfields property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYWOCUSTOMFIELDS() {
        return copywocustomfields;
    }

    /**
     * Sets the value of the copywocustomfields property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYWOCUSTOMFIELDS(String value) {
        this.copywocustomfields = value;
    }

    /**
     * Gets the value of the copyactivities property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYACTIVITIES() {
        return copyactivities;
    }

    /**
     * Sets the value of the copyactivities property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYACTIVITIES(String value) {
        this.copyactivities = value;
    }

    /**
     * Gets the value of the copyactivitycomments property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYACTIVITYCOMMENTS() {
        return copyactivitycomments;
    }

    /**
     * Sets the value of the copyactivitycomments property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYACTIVITYCOMMENTS(String value) {
        this.copyactivitycomments = value;
    }

    /**
     * Gets the value of the copychildren property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYCHILDREN() {
        return copychildren;
    }

    /**
     * Sets the value of the copychildren property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYCHILDREN(String value) {
        this.copychildren = value;
    }

    /**
     * Gets the value of the copytools property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOPYTOOLS() {
        return copytools;
    }

    /**
     * Sets the value of the copytools property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOPYTOOLS(String value) {
        this.copytools = value;
    }

}
